@@ -1,10 +1,10 @@
 # @package      hubzero-submit-client
 # @file         JobScanner.py
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -30,6 +30,7 @@ import os
 import os.path
 import math
 import re      # Regexp: http://docs.python.org/library/re.html
+import traceback
 
 import curses # <-- docs at: http://docs.python.org/library/curses.html
 import curses.ascii   # <-- docs at http://docs.python.org/library/curses.ascii.html
@@ -1590,10 +1591,10 @@ in order for you to be able to run statussheet.py!
          # color; user can test with has_color() later on.  The try/catch
          # works around a minor bit of over-conscientiousness in the curses
          # module -- the error return from C start_color() is ignorable.
-         try:
-            curses.start_color()
-         except:
-            pass
+#        try:
+#           curses.start_color()
+#        except:
+#           pass
 
          self.setUpCurses()
          self.initializeWindowSettings(self.mainInfo.getCurrent())
@@ -1649,15 +1650,35 @@ in order for you to be able to run statussheet.py!
             if self.cursesKeypadSetting:
                self.standardScreen.keypad(0)
                self.cursesKeypadSetting = False
+      except curses.error, err:
+         sys.stderr.write("%s\n" % (traceback.format_exc()))
+      except:
+         pass
+
+      try:
          if not self.cursesEcho:
             curses.echo()
             self.cursesEcho = True
+      except curses.error, err:
+         sys.stderr.write("%s\n" % (traceback.format_exc()))
+      except:
+         pass
+
+      try:
          if self.cursesCbreak:
             curses.nocbreak()
             self.cursesCbreak = False
+      except curses.error, err:
+         sys.stderr.write("%s\n" % (traceback.format_exc()))
+      except:
+         pass
+
+      try:
          if self.cursesInitialized:
             curses.endwin()
             self.cursesInitialized = False
+      except curses.error, err:
+         sys.stderr.write("%s\n" % (traceback.format_exc()))
       except:
          pass
 
